==> openshift-model-monitoring-5.12.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/RouteBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RouteBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.Route,io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteBuilder>{
  public RouteBuilder() {
    this(false);
  }
  public RouteBuilder(java.lang.Boolean validationEnabled) {
    this(new Route(), validationEnabled);
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Route(), validationEnabled);
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Route instance) {
    this(fluent, instance, false);
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Route instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContinue(instance.getContinue()); 
    fluent.withGroupBy(instance.getGroupBy()); 
    fluent.withGroupInterval(instance.getGroupInterval()); 
    fluent.withGroupWait(instance.getGroupWait()); 
    fluent.withMatchers(instance.getMatchers()); 
    fluent.withReceiver(instance.getReceiver()); 
    fluent.withRepeatInterval(instance.getRepeatInterval()); 
    fluent.withRoutes(instance.getRoutes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Route instance) {
    this(instance,false);
  }
  public RouteBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Route instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContinue(instance.getContinue()); 
    this.withGroupBy(instance.getGroupBy()); 
    this.withGroupInterval(instance.getGroupInterval()); 
    this.withGroupWait(instance.getGroupWait()); 
    this.withMatchers(instance.getMatchers()); 
    this.withReceiver(instance.getReceiver()); 
    this.withRepeatInterval(instance.getRepeatInterval()); 
    this.withRoutes(instance.getRoutes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.RouteFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.Route build() {
    Route buildable = new Route(fluent.getContinue(),fluent.getGroupBy(),fluent.getGroupInterval(),fluent.getGroupWait(),fluent.getMatchers(),fluent.getReceiver(),fluent.getRepeatInterval(),fluent.getRoutes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteBuilder that = (RouteBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/RouteBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RouteBuilder extends RouteFluentImpl<RouteBuilder> implements VisitableBuilder<Route,RouteBuilder>{
  public RouteBuilder() {
    this(false);
  }
  public RouteBuilder(Boolean validationEnabled) {
    this(new Route(), validationEnabled);
  }
  public RouteBuilder(RouteFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteBuilder(RouteFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Route(), validationEnabled);
  }
  public RouteBuilder(RouteFluent<?> fluent,Route instance) {
    this(fluent, instance, false);
  }
  public RouteBuilder(RouteFluent<?> fluent,Route instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContinue(instance.getContinue()); 
    fluent.withGroupBy(instance.getGroupBy()); 
    fluent.withGroupInterval(instance.getGroupInterval()); 
    fluent.withGroupWait(instance.getGroupWait()); 
    fluent.withMatchers(instance.getMatchers()); 
    fluent.withReceiver(instance.getReceiver()); 
    fluent.withRepeatInterval(instance.getRepeatInterval()); 
    fluent.withRoutes(instance.getRoutes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteBuilder(Route instance) {
    this(instance,false);
  }
  public RouteBuilder(Route instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withContinue(instance.getContinue()); 
    this.withGroupBy(instance.getGroupBy()); 
    this.withGroupInterval(instance.getGroupInterval()); 
    this.withGroupWait(instance.getGroupWait()); 
    this.withMatchers(instance.getMatchers()); 
    this.withReceiver(instance.getReceiver()); 
    this.withRepeatInterval(instance.getRepeatInterval()); 
    this.withRoutes(instance.getRoutes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RouteFluent<?> fluent;
  Boolean validationEnabled;
  public Route build() {
    Route buildable = new Route(fluent.getContinue(),fluent.getGroupBy(),fluent.getGroupInterval(),fluent.getGroupWait(),fluent.getMatchers(),fluent.getReceiver(),fluent.getRepeatInterval(),fluent.getRoutes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
